# pysqa
Simple queue adapter for Python

[![Build Status](https://travis-ci.org/pysqa/pysqa.svg?branch=master)](https://travis-ci.org/pysqa/pysqa)
[![Build status](https://ci.appveyor.com/api/projects/status/90cb1w7a57fql52q/branch/master?svg=true)](https://ci.appveyor.com/project/jan-janssen/pysqa/branch/master)
